package com.huiju.estateagents.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaBuilding;
import com.huiju.estateagents.entity.TaBuildingDynamic;
import com.huiju.estateagents.mapper.TaBuildingDynamicMapper;
import com.huiju.estateagents.mapper.TaBuildingMapper;
import com.huiju.estateagents.service.ITaBuildingDynamicService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.propertyeditors.CustomDateEditor;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.ServletRequestDataBinder;

import javax.servlet.http.HttpServletRequest;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 * <p>
 * 项目动态表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-03-21
 */
@Service
public class TaBuildingDynamicServiceImpl extends ServiceImpl<TaBuildingDynamicMapper, TaBuildingDynamic> implements ITaBuildingDynamicService {

    @Autowired
    private TaBuildingDynamicMapper buildingDynamicMapper;

    @Autowired
    private TaBuildingMapper buildingMapper;

    protected void initBinder(HttpServletRequest request, ServletRequestDataBinder binder) throws Exception {
        DateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        CustomDateEditor editor = new CustomDateEditor(df, true);//true表示允许为空，false反之
        binder.registerCustomEditor(Date.class, editor);
    }
    @Override
    public ResponseBean iBuildingDynamicList(Integer pageNum, Integer pageSize, String name, String buildingId) {
        Page<TaBuildingDynamic> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);

        IPage<TaBuildingDynamic> buildingDynamic = buildingDynamicMapper.buildingDynamicList(page, name, buildingId);
        List<TaBuildingDynamic> buildingDynamicList=buildingDynamic.getRecords();

        HashMap hashMap= new HashMap<>();
        hashMap.put("list",buildingDynamicList);
        hashMap.put("total",buildingDynamic.getTotal());
        hashMap.put("pageNum",buildingDynamic.getCurrent());
        hashMap.put("pageSize",buildingDynamic.getSize());
        return ResponseBean.success(hashMap);
    }

    @Override
    public ResponseBean iBuildingDynamicSelectId(String id) {
        TaBuildingDynamic buildingDynamicList= buildingDynamicMapper.iBuildingDynamicSelectId(id);
        return ResponseBean.success(buildingDynamicList);
    }

    @Override
    public ResponseBean getWxBuildingDynamiceList(Integer pageNum, Integer pageSize) {
        Page<TaBuildingDynamic> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("status", "1");
        buildingDynamicQueryWrapper.orderByDesc("create_date");
        IPage<TaBuildingDynamic> buildingDynamicIPage = buildingDynamicMapper.selectPage(page, buildingDynamicQueryWrapper);
        List<TaBuildingDynamic> records = buildingDynamicIPage.getRecords();
        records.forEach(e -> {
            QueryWrapper<TaBuilding> buildingQueryWrapper = new QueryWrapper<>();
            buildingQueryWrapper.eq("building_id", e.getBuildingId());
            TaBuilding building = buildingMapper.selectOne(buildingQueryWrapper);
            e.setBuilding(building);
        });

        return ResponseBean.success(buildingDynamicIPage);
    }

    @Override
    public ResponseBean getWxBuildingDynamiceInfo(String dynamicId) {
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", dynamicId);
        TaBuildingDynamic buildingDynamic = buildingDynamicMapper.selectOne(buildingDynamicQueryWrapper);
        return ResponseBean.success(buildingDynamic);
    }

    @Override
    public ResponseBean buildingDynamicAdd(HashMap map) {
        TaBuildingDynamic buildingDynamic= new TaBuildingDynamic();
        Date time = (Date)map.get("publishDate");
        Instant instant = time.toInstant();
        ZoneId zoneId = ZoneId.systemDefault();
        LocalDateTime localDateTime = instant.atZone(zoneId).toLocalDateTime();

//        buildingDynamic.setDynamicId(idGen.nextId()+"");
        buildingDynamic.setBuildingId(map.get("buildingId")+"");
        buildingDynamic.setImgUrl((String) map.get("imgUrl"));
        buildingDynamic.setDesc(map.get("desc")+"");
        buildingDynamic.setUrl(map.get("url")+"");
        buildingDynamic.setTitle(map.get("title")+"");
        buildingDynamic.setPublishDate(localDateTime);
        buildingDynamic.setStatus(1);
        buildingDynamic.setCreateDate(LocalDateTime.now());

        buildingDynamicMapper.insertBuildingDynamic(buildingDynamic);
        return ResponseBean.success("成功");
    }

    @Override
    public ResponseBean buildingDynamicDelete(String id) {
        TaBuildingDynamic buildingDynamic= new TaBuildingDynamic();
        buildingDynamic.setDynamicId(id);
        buildingDynamic.setStatus(-1);
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.eq("dynamic_id", id);
        buildingDynamicMapper.update(buildingDynamic,buildingDynamicQueryWrapper);
        return ResponseBean.success("成功");
    }

    @Override
    public ResponseBean buildingDynamicUpdate(HashMap<Object, Object> map) {
        TaBuildingDynamic buildingDynamic= new TaBuildingDynamic();

        Date time = (Date)map.get("publishDate");
        Instant instant = time.toInstant();
        ZoneId zoneId = ZoneId.systemDefault();
        LocalDateTime localDateTime = instant.atZone(zoneId).toLocalDateTime();

        buildingDynamic.setDynamicId(map.get("dynamicId")+"");
        buildingDynamic.setBuildingId(map.get("buildingId")+"");
        buildingDynamic.setImgUrl((String) map.get("imgUrl"));
        buildingDynamic.setDesc(map.get("desc")+"");
        buildingDynamic.setUrl(map.get("url")+"");
        buildingDynamic.setTitle(map.get("title")+"");
        buildingDynamic.setPublishDate(localDateTime);
        buildingDynamic.setStatus(1);
        buildingDynamic.setCreateDate(LocalDateTime.now());

        buildingDynamicMapper.buildingDynamicUpdate(buildingDynamic);
        return ResponseBean.success("成功");
    }


}
